PCB Environment: NavTriangulation Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Protected Attributes
NavTriangulation Class Referenceabstract

Interface to the Delaunay triangulation. More...

`#include <NavTriangulation.hpp>`

## Public Member Functions
| NavTriangulation (NavGrid &nav)
virtual uint | getNavIdx (const Point_2 &, uint z) const =0
virtual bool | findPathAStar (std::vector< NavTri * > &searchArea, Connection &)=0
virtual void | insertRoute (const Connection &)=0
virtual void | removeRoute (const Connection &)=0
const std::vector< NavTri > & | getNavTris () const
uint16_t | incSearchSeq ()
uint16_t | getSearchSeq () const
NavTri & | getNavTri (uint i)
NavTri * | getNavTri (const Point_2 &v, uint z)
const NavTri & | getNavTri (uint i) const
const NavTri * | getNavTri (const Point_2 &v, uint z) const
virtual PyObject * | getFaceGraphPy () const
virtual PyObject * | getLineGraphPy () const

## Protected Attributes
NavGrid & | mNav
std::vector< NavTri > | mNavTris
uint | mZ0 {0}
uint | mZ1 {0}
uint16_t | mSearchSeq {0}

## Detailed Description

Interface to the Delaunay triangulation.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavTriangulation.hpp